@@ -1,5 +1,5 @@
 package Crayon;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use 5.006;
 use strict;
 use warnings;
@@ -171,7 +171,7 @@ sub _flattern_struct {
 		elsif (ref $struct->{$s}) {
 			my $k = $key ? $s =~ m/^\&(.*)/ ? $key . ':' . $1 : $key . ' ' . $s : $s;
 			$self->_flattern_struct($struct->{$s}, $k, $flat);
-			$flat->{$k}->{VARIABLES} = $scp if $scp;
+			$flat->{$k}->{VARIABLES} = $self->bm->merge($scp, $flat->{$k}->{VARIABLES} || {}) if $scp;
 		}
 		else {
 			$flat->{$key}->{$s} = $struct->{$s};
